#
# spec file for package borgmatic
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           borgmatic
Version:        1.1.15
Release:        lp151.2.4
Summary:        Automation tool for borgbackup
License:        GPL-3.0
Group:          Productivity/Archiving/Backup
Url:            https://torsion.org/borgmatic/
Source:         borgmatic-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  python3 >= 3.4
BuildRequires:  python3-devel
BuildRequires:  python3-ruamel.yaml
BuildRequires:  python3-setuptools
BuildRequires:  systemd-devel
# To create the manpage
BuildRequires:  pandoc
# testing requirements
BuildRequires:  python3-flexmock
BuildRequires:  python3-pykwalify
BuildRequires:  python3-pytest
Requires:       python3-pykwalify
Requires:       python3-ruamel.yaml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
borgmatic is a Python wrapper script for the Borg backup software
that initiates a backup, prunes any old backups according to a
retention policy, and validates backups for consistency. The script
supports specifying your settings in a declarative configuration file
rather than having to put them all on the command-line, and handles
common errors.

%prep
%setup -q -n %{name}
# test_version.py fails because of assert '1.0.3.dev0\n' == '1.0.3-dev\n', so we just remove it
rm borgmatic/tests/integration/test_version.py

# Make sample files use the borgmatic command on /usr/bin, not /usr/local/bin
perl -pi -e "s,PATH=\\$PATH:/usr/local/bin /usr/local/bin/borgmatic,/usr/bin/borgmatic," sample/cron/borgmatic
perl -pi -e "s,/usr/local/bin/borgmatic,/usr/bin/borgmatic," sample/systemd/borgmatic.service
perl -pi -e "s,ruamel.yaml<=0.15,ruamel.yaml," setup.py

%build
# Create the manpage
pandoc -s -f markdown -t man README.md -o borgmatic.1

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}%{_sysconfdir}/borgmatic
install -d %{buildroot}%{_sysconfdir}/borgmatic.d
install -d %{buildroot}%{_docdir}/%{name}/sample/cron
install -m 0644 sample/cron/borgmatic %{buildroot}%{_docdir}/%{name}/sample/cron/
install -d %{buildroot}%{_unitdir}/
install -m 0644 sample/systemd/borgmatic* %{buildroot}%{_unitdir}/

install -D -m 0644 borgmatic.1 %{buildroot}%{_mandir}/man1/borgmatic.1
mkdir -p %{buildroot}/usr/sbin
ln -s /usr/sbin/service %{buildroot}/usr/sbin/rcborgmatic

%check
# testing the build is a little awkward, since the original testsuite is based on tox and
# tox tries to create a virtual environment, that we need tight control on in order to get
# it to behave in our build system (offline mode, use site packages). OTOH, without the
# venv, we face problems with setuptools (borg uses pkg_resources to locate the installed
# package), while py.test relies on the usual module handling. <hpj@urpla.net>
pyvenv --system-site-packages --without-pip borgmatic-env
source borgmatic-env/bin/activate
python3 setup.py install
LANG=en_US.UTF-8 PYTHONPATH=$(pwd) py.test -v --pyargs borgmatic

%post
%service_add_post borgmatic.service
if [ "$1" == 1 -a ! -f "/etc/borgmatic/config.yaml" ]; then
    /usr/bin/generate-borgmatic-config
elif [ "$1" == 2 ]; then
    if [ -f "/etc/borgmatic/config" -a ! -f "/etc/borgmatic/config.yaml" ]; then
       echo "The configuration files have changed. /usr/bin/upgrade-borgmatic-config will be run now to upgrade the configuration to the new format."
       echo ""
       /usr/bin/upgrade-borgmatic-config
    fi
fi

%pre
%service_add_pre borgmatic.service

%preun
%service_del_preun borgmatic.service

%postun
%service_del_postun borgmatic.service

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE NEWS README.md
%config %ghost %{_sysconfdir}/borgmatic/config.yaml
%dir %{_sysconfdir}/borgmatic
%dir %{_sysconfdir}/borgmatic.d
%dir %{_docdir}/%{name}/sample
%dir %{_docdir}/%{name}/sample/cron
%{python3_sitelib}/borgmatic/
%{python3_sitelib}/borgmatic-%{version}-py%{py3_ver}.egg-info
%{_unitdir}/borgmatic.service
%{_unitdir}/borgmatic.timer
%{_bindir}/borgmatic
%{_sbindir}/rcborgmatic
%{_bindir}/generate-borgmatic-config
%{_bindir}/upgrade-borgmatic-config
%{_mandir}/man1/borgmatic.1%{ext_man}
%{_docdir}/%{name}/sample/cron

%changelog
* Tue Mar 27 2018 t.gruner@katodev.de
- Use README.md form source
- Add borgmatic.d folder in /etc for config files
- Update to 1.1.15
  * Support for Borg BORG_PASSCOMMAND environment variable to read a password from an external file.
  * Fix for Borg create error when using borgmatic's --dry-run and --verbosity options together.
  Work-around for behavior introduced in Borg 1.1.3: https://github.com/borgbackup/borg/issues/3298
  * #55: Fix for missing tags/releases on Gitea and GitHub project hosting.
  * #56: Support for Borg --lock-wait option for the maximum wait for a repository/cache lock.
  * #58: Support for using tilde in exclude_patterns to reference home directory.
* Tue Jan 30 2018 alarrosa@suse.com
- Removed _service file. Borgmatic uses to have frequent releases these days.
- Update to 1.1.14
  * Fix for typo in --patterns-from option.
  * Support for Borg --dry-run option via borgmatic command-line.
- Update to 1.1.13
  * Fix for incorrect consistency check flags passed to Borg when all three checks ("repository",
    "archives", and "extract") are specified in borgmatic configuration.
  * Add "local_path" to configuration for specifying an alternative Borg executable path.
  * Support for Borg experimental --patterns-from and --patterns options for specifying mixed
    includes/excludes.
  * Moved issue tracker from Taiga to integrated Gitea tracker at
    https://projects.torsion.org/witten/borgmatic/issues
- Update to 1.1.12
  * Declare dependency on pykwalify 1.6 or above, as older versions yield "Unknown key: version"
    rule errors.
  * Support for Borg --keep-minutely prune option.
- Update to 1.1.11
  * Add "ssh_command" to configuration for specifying a custom SSH command or options.
  * Fix for incorrect /etc/borgmatic.d/ configuration path probing on macOS. This problem manifested
    as an error on startup: "[Errno 2] No such file or directory: '/etc/borgmatic.d'".
- Update to 1.1.10
  * Pass several Unix signals through to child processes like Borg. This means that Borg now properly
    shuts down if borgmatic is terminated (e.g. due to a system suspend).
  * Support for using tilde in repository paths to reference home directory.
  * Support for Borg --files-cache option for setting the files cache operation mode.
  * Support for Borg --remote-ratelimit option for limiting upload rate.
  * Log invoked Borg commands when at highest verbosity level.
* Sun Oct 29 2017 alarrosa@suse.com
- Upstream moved from mercurial to git, so updated _service accordingly,
  updated source code to 6e9e7c4 and set all services mode to disabled.
- Fixed a too restrictive python3-ruamel.yaml version requirement
  in the source code
- Add a rcborgmatic symlink as required by the suse-missing-rclink rpmlint check
* Wed Sep 20 2017 alarrosa@suse.com
- Update to 1.1.9dev0-201
  * #29: Support for using tilde in source directory path to reference home directory.
- python3-ruamel.yaml and python3-pykwalify are now required
- Update to 1.1.8
  * #39: Fix to make /etc/borgmatic/config.yaml optional rather than required when using the default
    config paths.
- Update to 1.1.7
  * #28: Add "archive_name_format" to configuration for customizing archive names.
  * Fix for traceback when "exclude_from" value is empty in configuration file.
  * When pruning, make highest verbosity level list archives kept and pruned.
  * Clarification of Python 3 pip usage in documentation.
- Update to 1.1.6
  * #12, #35: Support for Borg --exclude-from, --exclude-caches, and --exclude-if-present options.
- Update to 1.1.5
  * #34: New "extract" consistency check that performs a dry-run extraction of the most recent
    archive.
- Update to 1.1.4
  * #17: Added command-line flags for performing a borgmatic run with only pruning, creating, or
    checking enabled. This supports use cases like running consistency checks from a different cron
    job with a different frequency, or running pruning with a different verbosity level.
- Update to 1.1.3
  * #14: Support for running multiple config files in /etc/borgmatic.d/ from a single borgmatic run.
  * Fix for generate-borgmatic-config writing config with invalid one_file_system value.
- Update to 1.1.2
  * #32: Fix for passing check_last as integer to subprocess when calling Borg.
- Update to 1.1.1
  * Part of #32: Fix for upgrade-borgmatic-config converting check_last option as a string instead of
    an integer.
  * Fix for upgrade-borgmatic-config erroring when consistency checks option is not present.
- Update to 1.1.0
  * Switched config file format to YAML. Run upgrade-borgmatic-config to upgrade.
  * Added generate-borgmatic-config command for initial config creation.
  * Dropped Python 2 support. Now Python 3 only.
  * #18: Fix for README mention of sample files not included in package.
  * #22: Sample files for triggering borgmatic from a systemd timer.
  * Support for backing up to multiple repositories.
  * To free up space, now pruning backups prior to creating a new backup.
  * Enabled test coverage output during tox runs.
  * Added logo.
* Wed Mar  8 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Sun Oct 30 2016 jengelh@inai.de
- Trim and wrap description
* Thu Oct 13 2016 alarrosa@suse.com
- version 1.0.3-dev: initial build
